@@ -1,4 +1,4 @@
 #! /usr/bin/env bash
 $EXTRACTRC `find . -name "*.ui"` >> rc.cpp || exit 11
-$XGETTEXT `find . -name "*.cpp"` -o $podir/telepathy-contactslist-prototype.pot
+$XGETTEXT `find . -name "*.cpp"` -o $podir/telepathy-kde-contactlist.pot
 rm -f rc.cpp
